import { DeepFields } from '../types';
export declare function equals<V>(value: V): <T extends V>(check: T) => boolean;
export declare function notEquals<V>(value: V): <T extends V>(check: T) => boolean;
/**
 * Creates a function which will reduce an object type down to one of its named properties.
 *
 * @param field The name of a property for an object type.
 */
export declare function getField<K extends PropertyKey>(field: K): <T extends Record<K, unknown>>(obj: T) => Pick<T, K>;
/**
 * Creates a function which will reduce an object type down to one that excludes a named property.
 *
 * @param field The name of a property for an object type.
 */
export declare function removeField<K extends PropertyKey>(field: K): <T extends Partial<Record<K, unknown>>>(obj: T) => Omit<T, K>;
export declare const removeId: <T extends Partial<Record<"id", unknown>>>(obj: T) => Omit<T, "id">;
/**
 * Creates a function which will map an object to a new one with an additional named property.
 *
 * @param field The name of a property for an object type.
 */
export declare function addField<K extends PropertyKey>(field: K): <V extends unknown>(value: V) => <T extends Record<string, unknown>>(obj: T) => T & Record<K, V>;
/**
 * Creates a function which will reduce an object type down to a subset of its named properties.
 *
 * @param fields A list of property names for an object type.
 */
export declare function getFields<K extends PropertyKey>(...fields: K[]): <T extends Record<K, unknown>>(obj: T) => Pick<T, K>;
/**
 * Works like getField except it can get properties for nested object fields.
 *
 * For example, if we have an object like: { A: { B: { C: true } } }
 * and we get these fields: A, B, C
 * then we will reduce the original object to A.B.C which is the value true.
 *
 * @param fields A list of property names
 */
export declare function getPath<T extends Record<string, unknown>>(...fields: Array<DeepFields<T>>): (obj: T) => any;
/**
 * Create a function that composes a list of functions
 *
 * @param fns A list of functions to be used in the pipe
 */
export declare function pipe(...fns: Array<(arg: any) => any>): <I>(input: I) => I;
